/**
@license
Copyright 2018 The Advanced REST client authors <arc@mulesoft.com>
Licensed under the Apache License, Version 2.0 (the "License"); you may not
use this file except in compliance with the License. You may obtain a copy of
the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
License for the specific language governing permissions and limitations under
the License.
*/
/*
The API Console main stylesheet.
It is a Polymer's custom style element. It will propagate variables and mixins
to all elements.
*/
import '../../@polymer/polymer/lib/elements/custom-style.js';
import '../../@webcomponents/shadycss/entrypoints/apply-shim.js';
import '../../@polymer/polymer/lib/elements/custom-style.js';
import '../../@polymer/paper-styles/typography.js';
import '../../@polymer/paper-styles/default-theme.js';
const $_documentContainer = document.createElement('template');

$_documentContainer.innerHTML = `<custom-style>
  <style is="custom-style">
  html {
    --primary-color: var(--arc-color-primary, #00709a);
    --secondary-color: var(--arc-color-secondary, #506773);
    --primary-background-color: var(--arc-color-primary-background, #fff);
    --accent-color: var(--arc-accent-color, #cc143c);
    --error-color: var(--arc-error-color, #dd2c00);

    /* Font definitions user in ARC and API components */
    --arc-font-common-base: {
      font-family: var(--arc-font-family, 'Roboto', 'Noto', sans-serif);
      -webkit-font-smoothing: antialiased;
    };

    --arc-font-common-code: {
      font-family: var(--arc-font-family-code, 'Roboto Mono', 'Consolas', 'Menlo', monospace);
      -webkit-font-smoothing: antialiased;
    };

    --arc-font-common-expensive-kerning: {
      text-rendering: optimizeLegibility;
    };

    --arc-font-common-nowrap: {
      white-space: nowrap;
      overflow: hidden;
      text-overflow: ellipsis;
    };

    --arc-font-display1: {
      @apply --arc-font-common-base;
      font-size: 34px;
      font-weight: 400;
      letter-spacing: -.01em;
      line-height: 40px;
      word-break: break-all;
    };

    --arc-font-headline: {
      @apply --arc-font-common-base;
      font-weight: 400;
      letter-spacing: -.012em;
      font-size: 24px;
      line-height: 32px;
      word-break: break-all;
    };

    --arc-font-title: {
      @apply --arc-font-common-base;
      @apply --arc-font-common-nowrap;
      font-weight: 500;
      font-size: 18px;
      line-height: 28px;
      word-break: break-all;
    };

    --arc-font-subhead: {
      @apply --arc-font-common-base;
      font-weight: 400;
      font-size: 16px;
      line-height: 24px;
      word-break: break-all;
    };

    --arc-font-body2: {
      @apply --arc-font-common-base;
      font-size: 14px;
      font-weight: 500;
      line-height: 24px;
    };

    --arc-font-body1: {
      @apply --arc-font-common-base;

      font-size: 14px;
      font-weight: 400;
      line-height: 20px;
    };

    --arc-font-caption: {
      @apply --arc-font-common-base;
      @apply --arc-font-common-nowrap;

      font-size: 12px;
      font-weight: 400;
      letter-spacing: 0.011em;
      line-height: 20px;
    };

    --select-text: {
      @apply --arc-font-common-base;
      -webkit-user-select: text;
      cursor: text;
    };

    /* Navigation */
    --api-navigation-list-item-selected-background-color: var(--primary-color);
    --api-navigation-endpoint-toggle-icon-color: #9E9E9E;
    --api-navigation-endpoint-toggle-icon: {
      width: 32px;
      height: 32px;
      margin-right: 4px;
    };
    --api-navigation: {
      background-color: #F5F5F5;
    };
    --api-navigation-operation-endpoint-opened-background-color: #ECEFF1;

    /* Color of "help" icon in the editors in request panel */
    --hint-trigger-color: #455A64;
    --hint-trigger-hover-color: var(--primary-color);
    --api-form-action-icon-color: #455A64;
    --api-form-action-icon-hover-color: var(--primary-color);
    --api-form-action-button-color: #455A64;
    --api-form-action-button-hover-color: var(--primary-color);
    --from-row-action-icon-color: #455A64;
    --from-row-action-icon-color-hover: var(--primary-color);

    /* Method labels in method documentation title */
    --http-method-label-get-background-color: rgb(0, 128, 0);
    --http-method-label-get-color: #fff;
    --http-method-label-post-background-color: rgb(33, 150, 243);
    --http-method-label-post-color: #fff;
    --http-method-label-put-background-color: rgb(255, 165, 0);
    --http-method-label-put-color: #fff;
    --http-method-label-patch-background-color: rgb(156, 39, 176);
    --http-method-label-patch-color: #fff;
    --http-method-label-delete-background-color: rgb(244, 67, 54);
    --http-method-label-delete-color: #fff;

    /* Code snippets containers */
    --http-code-snippet-container-highlighted: {
      background-color: var(--code-background-color);
    };
    --http-code-snippet-line: {
      word-break: break-all;
      white-space: pre-wrap;
    };
    --http-code-snippet-container: {
      background-color: #e0e0e0;
      padding: 8px;
    };

    /* Paper tabs */
    --paper-tabs-selection-bar-color: var(--primary-color);
    --tabs-selection-width: 2px;
    --paper-tabs-selection-bar: {
      border-width: var(--tabs-selection-width);
      border-color: var(--primary-color);
    };
    --paper-tabs-content: {
      @apply --arc-font-common-base;
      height: calc(100% - var(--tabs-selection-width));
      border-bottom: var(--tabs-selection-width) solid rgba(39, 47, 51, .1);
      font-style: normal;
      color: rgba(0, 0, 0, 0.87);
    };
    --paper-tab-content-unselected: {
      color: rgba(0, 0, 0, 0.78);
    };
    --paper-tab-ink: rgb(39, 47, 51);

    /* The request editor */
    --api-request-editor-send-valid-button: {
      background-color: var(--primary-color);
      color: #fff;
    };

    --api-request-editor-abort-button: {
      background-color: var(--primary-color);
      color: #fff;
    };

    --api-request-editor-abort-button-hover: {
      background-color: var(--primary-color);
      color: #fff;
    };

    --api-request-editor-send-invalid-button: {
      background-color: var(--error-color);
      color: #fff;
    };

    --request-editor-section-padding: 8px 12px;

    /* Authorization panel */
    --stepper-step-number-background-color: var(--primary-color);
    --authorization-panel: {
      padding: var(--request-editor-section-padding);
    };

    /* URL parameters editor */
    --api-url-params-editor: {
      padding: var(--request-editor-section-padding);
    };

    --api-url-params-editor-editor-subheader: {
      @apply --arc-font-body2;
      font-size: 14px;
      padding: 0.73em 0;
      margin: 0;
      margin-right: 12px;
    };

    /* Headers editor */
    --api-headers-editor: {
      padding: var(--request-editor-section-padding);
    };

    /* Body editor */
    --api-body-editor: {
      padding: var(--request-editor-section-padding);
    };

    /* Paper-autocomplete must be styled to not go under the navigation */
    --paper-autocomplete: {
      max-width: calc(100vw - 256px - 48px);
    };

    /* Type documentation */
    --property-shape-document: {
      padding: 12px 0;
      border-bottom: 1px #CFD8DC dashed;
    };

    /* Code styling */
    --code-background-color: #f5f2f0;
    --code-block: {
      word-wrap: break-word;
    };

    --arc-link: {
      color: #1976D2;
    };

    --no-info-message: {
      @apply --arc-font-body1;
      font-style: italic;
      color: #616161;
    };
  }

  [narrow] {
    --narrow-request-editor-section-padding: 0px;
    --authorization-panel: {
      padding: var(--narrow-request-editor-section-padding);
    };
    --api-headers-editor: {
      padding: var(--narrow-request-editor-section-padding);
    };
    --api-body-editor: {
      padding: var(--narrow-request-editor-section-padding);
    };
    --api-url-params-editor: {
      padding: var(--narrow-request-editor-section-padding);
    };
    /* Query / URI parameters documentation styles */
    --api-parameters-document-title-narrow: {
      font-size: 17px;
    };

    /* Headers documentation styles */
    --api-headers-document-title-narrow: {
      font-size: 17px;
    };

    /* API method documentation styles */
    --api-method-documentation-title-narrow: {
      font-size: 22px;
      font-weight: 400;
    };
    --api-method-documentation-main-section-title-narrow: {
      font-size: 20px;
    };
    --api-method-documentation-subsection-title-narrow: {
      font-size: 17px;
    };
    /* Body documentation styles */
    --api-body-document-title-narrow: {
      font-size: 17px;
    };

    --api-console-main-content-margin-top: 12px;
  }
  </style>
</custom-style>`;

document.head.appendChild($_documentContainer.content);
